(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('axios'), require('debug'), require('colors'), require('crypto-js')) :
    typeof define === 'function' && define.amd ? define(['exports', 'axios', 'debug', 'colors', 'crypto-js'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.TsDingtalkRobot = {}, global.axios, global.debug, global.colors, global.CryptoJS));
}(this, (function (exports, axios, debug, colors, CryptoJS) { 'use strict';

    function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

    var axios__default = /*#__PURE__*/_interopDefaultLegacy(axios);
    var debug__default = /*#__PURE__*/_interopDefaultLegacy(debug);
    var colors__default = /*#__PURE__*/_interopDefaultLegacy(colors);
    var CryptoJS__default = /*#__PURE__*/_interopDefaultLegacy(CryptoJS);

    const Debugger = debug__default['default']('ts-dingtalk-robot');
    class Robot {
        constructor(option = {}) {
            this.webhook = 'https://oapi.dingtalk.com/robot/send';
            Object.assign(this, option);
            if (!this.accessToken) {
                throw new Error('accessToken is required!');
            }
            if (!this.secret) {
                console.warn(colors__default['default'].yellow('Secret is undefined'));
            }
        }
        getSign(timeStamp) {
            let signStr = '';
            if (this.secret) {
                signStr = CryptoJS__default['default'].enc.Base64.stringify(CryptoJS__default['default'].HmacSHA256(`${timeStamp}\n${this.secret}`, this.secret));
                Debugger('Sign string is %s, result is %s', `${timeStamp}\n${this.secret}`, signStr);
            }
            return signStr;
        }
        async request(body) {
            Debugger('Send message: %O ', body);
            try {
                const timestamp = Date.now();
                const sign = this.getSign(timestamp);
                const result = await axios__default['default'].post(this.webhook, body, {
                    params: {
                        timestamp,
                        sign,
                        access_token: this.accessToken,
                    },
                    headers: {
                        'Content-Type': 'application/json',
                    },
                });
                Debugger('Result is %s, %s。', result.data.errcode, result.data.errmsg);
                if (result.data.errcode === 310000) {
                    console.error('Send Failed:', result.data);
                    Debugger('Please check safe config : %O', result.data);
                }
                return result;
            }
            catch (error) {
                if (error.toJSON) {
                    console.error(error.toJSON());
                }
                else {
                    console.error(error);
                }
            }
        }
        async send(message) {
            const body = message.get();
            return this.request(body);
        }
    }

    class MessageTemplateAbs {
        constructor() {
            this.canAt = false;
            this.isAtAll = false;
            this.atMobiles = new Set();
            this.atDingtalkIds = new Set();
            if (new.target === MessageTemplateAbs) {
                throw new Error('抽象类不可以实例化');
            }
        }
        render(options) {
            return Object.assign({
                msgtype: this.msgtype,
            }, options, this.canAt
                ? {
                    at: {
                        atMobiles: Array.from(this.atMobiles),
                        atDingtalkIds: Array.from(this.atDingtalkIds),
                        isAtAll: this.isAtAll,
                    },
                }
                : {});
        }
        get() {
            throw new Error('抽象方法render不可以调用');
        }
        toJsonString() {
            throw new Error('抽象方法toJsonString不可以调用');
        }
        atAll() {
            this.isAtAll = true;
            return this;
        }
        atPhone(phones) {
            if (phones instanceof Array) {
                phones.forEach((phone) => {
                    this.atMobiles.add(phone);
                });
            }
            else {
                this.atMobiles.add(phones);
            }
            return this;
        }
        atId(ids) {
            if (ids instanceof Array) {
                ids.forEach((phone) => {
                    this.atDingtalkIds.add(phone);
                });
            }
            else {
                this.atDingtalkIds.add(ids);
            }
            return this;
        }
    }

    class ActionCard extends MessageTemplateAbs {
        constructor() {
            super();
            this.msgtype = 'actionCard';
            this.title = '';
            this.text = '';
            this.hideAvatar = 0;
            this.btnOrientation = 0;
            this.singleTitle = '';
            this.singleURL = '';
            this.btns = [];
        }
        setBtns(btns) {
            this.btns = this.btns.concat(btns);
            return this;
        }
        setSingleTitle(title) {
            this.singleTitle = title;
            return this;
        }
        setSingleURL(url) {
            this.singleURL = url;
            return this;
        }
        setTitle(title) {
            this.title = title;
            return this;
        }
        setText(content) {
            this.text = content;
            return this;
        }
        setBtnOrientation(flag) {
            this.btnOrientation = flag;
            return this;
        }
        setHideAvatar(flag) {
            this.hideAvatar = flag;
            return this;
        }
        get() {
            return this.render({
                actionCard: {
                    title: this.title,
                    text: this.text,
                    hideAvatar: this.hideAvatar,
                    btnOrientation: this.btnOrientation,
                    btns: this.btns,
                    singleTitle: this.singleTitle,
                    singleURL: this.singleURL,
                },
            });
        }
    }

    class FeedCard extends MessageTemplateAbs {
        constructor(links) {
            super();
            this.msgtype = 'feedCard';
            this.links = links || [];
        }
        addLinks(links) {
            this.links = this.links.concat(links);
            return this;
        }
        get() {
            return this.render({
                feedCard: {
                    links: this.links,
                },
            });
        }
    }

    class Link extends MessageTemplateAbs {
        constructor(content) {
            super();
            this.msgtype = 'link';
            this.title = '';
            this.messageUrl = '';
            this.picUrl = '';
            this.setContent(content);
        }
        setContent(content) {
            this.text = content;
            return this;
        }
        setTitle(title) {
            this.title = title;
            return this;
        }
        setImage(image) {
            this.picUrl = image;
            return this;
        }
        setUrl(url) {
            this.messageUrl = url;
            return this;
        }
        get() {
            return this.render({
                link: {
                    text: this.text,
                    title: this.title,
                    picUrl: this.picUrl,
                    messageUrl: this.messageUrl,
                },
            });
        }
    }

    class Markdown extends MessageTemplateAbs {
        constructor() {
            super();
            this.msgtype = 'markdown';
            this.canAt = true;
            this.items = [];
        }
        setTitle(title) {
            this.title = title;
            return this;
        }
        add(text) {
            if (Array.isArray(text)) {
                this.items.concat(text);
            }
            else {
                this.items.push(text);
            }
            return this;
        }
        get() {
            return this.render({
                markdown: {
                    title: this.title,
                    text: this.items.join('\n'),
                },
            });
        }
    }

    class Text extends MessageTemplateAbs {
        constructor(content) {
            super();
            this.msgtype = 'text';
            this.canAt = true;
            this.setContent(content);
        }
        setContent(content) {
            this.content = content;
            return this;
        }
        get() {
            return this.render({
                text: {
                    content: this.content,
                },
            });
        }
    }

    exports.ActionCard = ActionCard;
    exports.FeedCard = FeedCard;
    exports.Link = Link;
    exports.Markdown = Markdown;
    exports.MessageTemplateAbs = MessageTemplateAbs;
    exports.Robot = Robot;
    exports.Text = Text;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=index.umd.js.map
